pub fn shadow_client_factory<T: Signer>(
signer: T,
url: &str,
auth: Option<String>,
) -> ShadowDriveClient<T>Expand description
We either create an authenticated client with default auth headers, or else we simply use the RpcClient provided by the normal ShadowDriveClient constructor.